FROM rocm/dev-ubuntu-22.04:5.5

USER root

# Update to latest library version
ENV DEBIAN_FRONTEND="noninteractive"
RUN apt update
RUN apt full-upgrade -y
RUN apt install python3 python3-dev git build-essential cmake libsqlite3-0 libsqlite3-dev -y

# Add groups and user
RUN groupmod -g 105 render
RUN useradd --create-home -G render,video --shell /bin/bash dlprim

USER dlprim
WORKDIR /home/dlprim

# Install PyTorch
RUN pip3 install torch torchvision torchaudio --index-url https://download.pytorch.org/whl/cpu

# Install OpenCL backend for PyTorch
RUN git clone --recurse-submodules https://github.com/artyom-beilis/pytorch_dlprim.git
RUN mkdir /home/dlprim/pytorch_dlprim/build
WORKDIR /home/dlprim/pytorch_dlprim/build
RUN cmake -DOCL_PATH=/opt/rocm-5.5.0/opencl/include/ -DOCL_LIB=/opt/rocm-5.5.0/opencl/lib/libOpenCL.so -DCMAKE_PREFIX_PATH=/home/dlprim/.local/lib/python3.10/site-packages/torch/share/cmake/Torch ..
RUN make -j16

# Create path to cache OpenCL kernels
RUN mkdir /home/dlprim/.dlprimitives

# Run test from OpenCL PyTorch
WORKDIR /home/dlprim/pytorch_dlprim/
ENTRYPOINT ["python3", "mnist.py", "--device", "ocl:0"]